@@ -39,43 +39,38 @@ class TaskListCommand(BaseCommand):
     option_list = BaseCommand.option_list + (
         make_option('--all', action='store_true',
                     dest='test_all', default=False,
-            help='Ignore PROJECT_APPS settings and run '
-                 'through all INSTALLED_APPS'),
+                    help='Ignore PROJECT_APPS settings and run through all INSTALLED_APPS'),
         make_option('--interactive', action='store_true',
                     dest='interactive', default=False,
-            help='Allow to ask user input'),
+                    help='Allow to ask user input'),
         make_option('--debug', action='store_true',
                     dest='debug', default=False,
-            help='Do not intercept stdout and stderr, '
-                 'friendly for console debuggers'),
+                    help='Do not intercept stdout and stderr, friendly for console debuggers'),
         make_option('--output-dir', dest='output_dir', default="reports",
-            help='Report files directory'),
+                    help='Report files directory'),
         make_option('--liveserver',
-            action='store', dest='liveserver', default=None,
-            help='Overrides the default address where the live server (used '
-                 'with LiveServerTestCase) is expected to run from. The '
-                 'default value is localhost:8081.')
+                    action='store', dest='liveserver', default=None,
+                    help='Overrides the default address where the live server (used '
+                    'with LiveServerTestCase) is expected to run from. The '
+                    'default value is localhost:8081.')
     )
 
     def __init__(self):
         super(TaskListCommand, self).__init__()
         self.tasks_cls = [import_module(module_name).Task
-                                for module_name in self.get_task_list()]
+                          for module_name in self.get_task_list()]
 
     def handle(self, *test_labels, **options):
         # options
         if options.get('liveserver') is not None:
-            os.environ['DJANGO_LIVE_TEST_SERVER_ADDRESS'] = \
-                                                        options['liveserver']
+            os.environ['DJANGO_LIVE_TEST_SERVER_ADDRESS'] = options['liveserver']
             del options['liveserver']
 
         # instantiate tasks
         self.tasks = self.get_tasks(*test_labels, **options)
 
         # subscribe
-        for signal_name, signal in inspect.getmembers(
-                                                signals,
-                                                predicate=lambda obj: obj):
+        for signal_name, signal in inspect.getmembers(signals, predicate=lambda obj: obj):
             for task in self.tasks:
                 signal_handler = getattr(task, signal_name, None)
                 if signal_handler:
@@ -88,7 +83,8 @@ class TaskListCommand(BaseCommand):
             interactive=options['interactive'],
             debug=options['debug'],
             verbosity=int(options.get('verbosity', 1)),
-            with_reports=options.get('with_reports', True))
+            with_reports=options.get('with_reports', True),
+            test_all=options.get('test_all', False))
 
         if test_runner.run_tests(test_labels):
             sys.exit(1)
@@ -118,7 +114,8 @@ class TaskListCommand(BaseCommand):
 
             if task_cls.option_list:
                 for option in task_cls.option_list:
-                    option_group.add_option(option)
+                    if option._long_opts and not parser.has_option(option._long_opts[0]):
+                        option_group.add_option(option)
                 parser.add_option_group(option_group)
 
         return parser
