@@ -10,5 +10,4 @@ class Command(TaskListCommand):
     def get_task_list(self):
         return getattr(settings, 'JENKINS_TASKS',
                        ('django_jenkins.tasks.run_pylint',
-                        'django_jenkins.tasks.with_coverage',
-                        'django_jenkins.tasks.django_tests',))
+                        'django_jenkins.tasks.with_coverage',))
