@@ -7,7 +7,8 @@ class Command(TaskListCommand):
     help = "Run pep8 over project apps"
     args = '[appname ...]'
     option_list = TaskListCommand.option_list + (
-        make_option('--pep8-file-output', action='store_true', dest='pep8_file_output', default=False,
+        make_option('--pep8-file-output', action='store_true',
+                    dest='pep8_file_output', default=False,
             help='Store pep8 report in file'),
     )
 
